@@ -1,5 +1,5 @@
 /*             This file is part of the New World OS project
---                Copyright (C) 2006, 2007  QRW Software
+--                 Copyright (C) 2006-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -20,6 +20,14 @@
 --      http://www.fsf.org/licenses
 --
 -- $Log: link_img_files.c,v $
+-- Revision 1.4  2008/09/01 00:23:06  jsedwards
+-- Fix year in copyright.  NO code changes.
+--
+-- Revision 1.3  2008/08/31 16:47:43  jsedwards
+-- Added assert around calls to nwos_read_variable_sized_object_from_disk and
+-- nwos_read_object_from_disk because they now return false if they fail,
+-- whereas before they asserted themselves.
+--
 -- Revision 1.2  2008/05/18 20:13:34  jsedwards
 -- Bug #1957144 - NO FIX! - This program should *NOT* be used, it was a hack
 -- to link revised files created by disc_list.  It is broken and links the
@@ -150,7 +158,7 @@ int main(int argc, char* argv[])
 
 	if (is_same_object(&object_class, &path_class_ref))
 	{
-	    nwos_read_variable_sized_object_from_disk(&path_list->references[i], kludge, sizeof(kludge), &get_path_object_size);
+	    assert(nwos_read_variable_sized_object_from_disk(&path_list->references[i], kludge, sizeof(kludge), &get_path_object_size));
 
 	    /* remember ptr_path_obj points to the kludge buffer */
 
@@ -173,11 +181,11 @@ int main(int argc, char* argv[])
 		    nwos_get_object_class(&ref_list->references[1], &object_class);
 		    assert(is_same_object(&object_class, &assoc_class_ref));
 
-		    nwos_read_object_from_disk(&ref_list->references[0], &old_assoc_obj, sizeof(old_assoc_obj));
-		    nwos_read_object_from_disk(&ref_list->references[1], &new_assoc_obj, sizeof(new_assoc_obj));
+		    assert(nwos_read_object_from_disk(&ref_list->references[0], &old_assoc_obj, sizeof(old_assoc_obj)));
+		    assert(nwos_read_object_from_disk(&ref_list->references[1], &new_assoc_obj, sizeof(new_assoc_obj)));
 
-		    nwos_read_object_from_disk(&old_assoc_obj.file, &old_file, sizeof(old_file));
-		    nwos_read_object_from_disk(&new_assoc_obj.file, &new_file, sizeof(new_file));
+		    assert(nwos_read_object_from_disk(&old_assoc_obj.file, &old_file, sizeof(old_file)));
+		    assert(nwos_read_object_from_disk(&new_assoc_obj.file, &new_file, sizeof(new_file)));
 
 		    printf("%s: %d\n", name, num_refs);
 
