@@ -27,6 +27,9 @@
 --
 --
 -- $Log: list_public_spellings.c,v $
+-- Revision 1.9.2.1  2009/05/23 03:51:26  jsedwards
+-- Added include of disk_io.h to define file block size.
+--
 -- Revision 1.9  2009/03/08 19:38:10  jsedwards
 -- Fixed year in Copyright.
 --
@@ -71,6 +74,7 @@
 #include <unistd.h>
 
 #include "../crc32.h"
+#include "../disk_io.h"
 #include "../objectify.h"
 
 
