@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2005-2008  QRW Software
+--                 Copyright (C) 2005-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,10 @@
 --
 --
 -- $Log: date.c,v $
+-- Revision 1.41  2009/03/08 01:04:26  jsedwards
+-- Removed include of objectify_private.h and changed all calls to
+-- nwos_generate_new_completely_random_id to nwos_generate_new_id.
+--
 -- Revision 1.40  2008/09/01 00:10:49  jsedwards
 -- Fix copyright year.  NO code changes.
 --
@@ -190,7 +194,6 @@
 
 #include "crc32.h"
 #include "objectify.h"
-#include "objectify_private.h"
 
 
 static uint8 days_per_month[12] = { 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
@@ -365,7 +368,7 @@ void nwos_find_or_create_private_year(uint16 year, ObjRef* ref)
 
 	assert(nwos_read_object_from_disk(&public_year_ref, &year_obj, sizeof(year_obj)));
 
-	nwos_generate_new_completely_random_id(ref);
+	nwos_generate_new_id(ref);
 
 	snprintf(msg, sizeof(msg), "clone_year(%02x%02x%02x%02x) -> %02x%02x%02x%02x\n",
 		 public_year_ref.id[0], public_year_ref.id[1], public_year_ref.id[2], public_year_ref.id[3],
@@ -497,7 +500,7 @@ void nwos_find_or_create_private_month(uint8 month, ObjRef* ref)
 
 	assert(nwos_read_object_from_disk(&public_month_ref, &month_obj, sizeof(month_obj)));
 
-	nwos_generate_new_completely_random_id(ref);
+	nwos_generate_new_id(ref);
 
 	snprintf(msg, sizeof(msg), "clone_month(%02x%02x%02x%02x) -> %02x%02x%02x%02x\n",
 		 public_month_ref.id[0], public_month_ref.id[1], public_month_ref.id[2], public_month_ref.id[3],
@@ -637,7 +640,7 @@ void nwos_find_or_create_private_month_and_day(uint8 month, uint8 day, ObjRef* r
 
 	assert(nwos_read_object_from_disk(&public_month_and_day_ref, &month_and_day_obj, sizeof(month_and_day_obj)));
 
-	nwos_generate_new_completely_random_id(ref);
+	nwos_generate_new_id(ref);
 
 	snprintf(msg, sizeof(msg), "clone_month_and_day(%02x%02x%02x%02x) -> %02x%02x%02x%02x\n",
 		 public_month_and_day_ref.id[0], public_month_and_day_ref.id[1], public_month_and_day_ref.id[2], public_month_and_day_ref.id[3],
