@@ -27,6 +27,10 @@
 --
 --
 -- $Log: disc_list.c,v $
+-- Revision 1.35.2.1  2009/06/06 13:41:22  jsedwards
+-- Fix Bug #2740516 - Added new get_disc_id function that calls fgets and
+-- checks return value.
+--
 -- Revision 1.35  2009/03/19 11:38:21  jsedwards
 -- Wrapped call to nwos_set_security_level with ifdef CHANGE_SECURITY_TO_DENSITY
 -- because what was called security level stuff is temporarily disabled.
@@ -189,6 +193,26 @@ static char* file_names[MAX_FILES_PER_DISC_LIST];
 static ObjRef files[MAX_FILES_PER_DISC_LIST];
 
 
+static void get_disc_id(char* buffer, size_t bufsize)
+{
+    if (fgets(buffer, bufsize, stdin) == NULL)
+    {
+	fputc('\n', stderr);
+
+	if (feof(stdin))
+	{
+	    fprintf(stderr, "ERROR: received end of input from standard input when reading disc ID\n");
+	    exit(1);
+	}
+	else
+	{
+	    perror("reading disc ID");
+	    exit(1);
+	}
+    }
+}
+
+
 static size_t get_path_object_size(void* file_path_obj)
 {
     assert(((C_struct_File_Path*)file_path_obj)->count > 0);
@@ -357,7 +381,7 @@ int main(int argc, char* argv[])
 	printf("Disk id: ");
 	fflush(stdout);
 
-	fgets(id, sizeof(id), stdin);
+	get_disc_id(id, sizeof(id));
 
 	p = strchr(id, '\n');   /* find the newline char */
 
@@ -365,7 +389,7 @@ int main(int argc, char* argv[])
 	{
 	    while (p == NULL) 
 	    {
-		fgets(id, sizeof(id), stdin);
+		get_disc_id(id, sizeof(id));
 		p = strchr(id, '\n');   /* find the newline char */
 	    }
 	    printf("id was too long, must be less than %zd characters\n", sizeof(id) - 2);
