@@ -27,6 +27,9 @@
 --
 --
 -- $Log: expand_sparse.c,v $
+-- Revision 1.40.2.1  2009/06/06 13:51:11  jsedwards
+-- Fix Bug #2740516 - Changed to check return value from fgets.
+--
 -- Revision 1.40  2009/03/14 23:06:41  jsedwards
 -- Added include of the new backup.h file.
 --
@@ -276,7 +279,21 @@ int main(int argc, char* argv[])
 
     fflush(stderr);
 
-    fgets(answer, sizeof(answer), stdin);
+    if (fgets(answer, sizeof(answer), stdin) == NULL)
+    {
+	fputc('\n', stderr);
+
+	if (feof(stdin))
+	{
+	    fprintf(stderr, "ERROR: received end of input from standard input\n");
+	    exit(1);
+	}
+	else
+	{
+	    perror("reading answer to question");
+	    exit(1);
+	}
+    }
 
     printf("\n");
 
