@@ -27,6 +27,10 @@
 --
 --
 -- $Log: financial.c,v $
+-- Revision 1.10.2.1  2009/06/06 14:03:54  jsedwards
+-- Moved get_input function to new dialog.c file, renamed it to nwos_ask_user,
+-- and changed to call it.
+--
 -- Revision 1.10  2009/03/10 11:19:00  jsedwards
 -- Moved MAX_NUMBER_SIZE, MAX_ID_SIZE, MAX_ACCOUNT_NUMBER_SIZE, and
 -- MAX_CHECKING_SIZE to the objectify.h file and renamed.
@@ -608,27 +612,6 @@ void nwos_create_checking(ObjRef* account_ref, char* id, ObjRef* ref)
 
 
 
-static void get_input(char* descr, char* buffer, size_t size)
-{
-    char *ptr;
-
-    while (1)
-    {
-	printf("%s: ", descr);
-	fflush(stdout);
-	fgets(buffer, size, stdin);
-	ptr = strchr(buffer, '\n');
-	if (ptr != NULL)
-	{
-	    *ptr = '\0';
-	    break;
-	}
-	do { fgets(buffer, size, stdin); } while (strchr(buffer, '\n') == NULL);
-	printf("input too long - try again!\n");
-    }
-}
-
-
 void nwos_add_account()
 {
     char name[MAX_NAME_SIZE+2];
@@ -649,7 +632,7 @@ void nwos_add_account()
     ok = false;
     while (!ok)
     {
-	get_input("name of credit union", name, sizeof(name));
+	nwos_ask_user("name of credit union", name, sizeof(name));
 	if (*name == '\0') return;
 	ok = nwos_find_public_credit_union(name, &cu_ref);
 	if (!ok) printf("name not found in public credit union list.\n");
@@ -662,7 +645,7 @@ void nwos_add_account()
     ok = false;
     while (!ok)
     {
-	get_input("account number", number, sizeof(number));
+	nwos_ask_user("account number", number, sizeof(number));
 	if (*number == '\0') return;
 	ok = valid_number(number);
 	if (!ok) printf("number can only contain digits 0 to 9 and dash '-'.\n");
@@ -671,7 +654,7 @@ void nwos_add_account()
     ok = false;
     while (!ok)
     {
-	get_input("checking id", id, sizeof(id));
+	nwos_ask_user("checking id", id, sizeof(id));
 	if (*id == '\0') return;
 	ok = valid_id(id);
 	if (!ok) printf("id can only contain digits 0 to 9.\n");
