@@ -27,6 +27,28 @@
 --
 --
 -- $Log: gen_id.c,v $
+-- Revision 1.18.2.6  2009/06/09 12:39:19  jsedwards
+-- Changed to only create a new chunk island at random.
+--
+-- Revision 1.18.2.5  2009/06/09 10:59:20  jsedwards
+-- Renamed find_new_chunk_location function to find_new_random_chunk_location
+-- and made static.
+--
+-- Revision 1.18.2.4  2009/06/09 02:38:01  jsedwards
+-- Fix Bug #2803265 - changed to always allow two chunks, even for small files.
+--
+-- Revision 1.18.2.3  2009/06/07 22:30:33  jsedwards
+-- Fix Bug #2734284 - changed to only print warning about non-contiguous chunks
+-- if archive is disk and no more chunks are available, otherwise it allocates
+-- all new chunks.
+--
+-- Revision 1.18.2.2  2009/06/06 19:45:31  jsedwards
+-- Add a hack so that it doesn't create the private class definition object and
+-- it's associated reference list object at the first two locations in the chunk.
+--
+-- Revision 1.18.2.1  2009/05/18 12:28:15  jsedwards
+-- Fixed to compile correctly in PUBLIC MODE.
+--
 -- Revision 1.18  2009/04/04 13:18:11  jsedwards
 -- Moved code from nwos_check_blocks_available and created new
 -- find_starting_chunk_for_blocks function and then called it in several
@@ -177,6 +199,7 @@ void nwos_initialize_gen_id(void)
 
 static void log_estimate_results()
 {
+#ifndef PUBLIC_MODE
     char log_msg[128];
 
     uint32 actual = nwos_used_private_blocks - last_used_blocks;
@@ -184,6 +207,7 @@ static void log_estimate_results()
     snprintf(log_msg, sizeof(log_msg), "  block estimate: %u  actual: %u", block_estimate, actual);
 
     nwos_log(log_msg);
+#endif
 }
 
 /********************************************/
@@ -361,14 +385,7 @@ static int find_starting_chunk_for_blocks(uint32 estimated_blocks)
     uint32 available_blocks;
     int info_index;
 
-    if (estimated_blocks < (USABLE_BLOCKS_PER_CHUNK / 3))   /* if it is less than 1/3 of a chunk it should fit in 1 chunk */
-    {
-	maximum_chunks = 1;
-    }
-    else
-    {
-	maximum_chunks = estimated_blocks / USABLE_BLOCKS_PER_CHUNK + 2;
-    }
+    maximum_chunks = estimated_blocks / USABLE_BLOCKS_PER_CHUNK + 2;     /* always allow at least 2 chunks so that we use space at the end of the chunk */
 
     for (info_index = 0; info_index < nwos_used_private_chunks; info_index++)
     {
@@ -388,6 +405,101 @@ static int find_starting_chunk_for_blocks(uint32 estimated_blocks)
 }
 
 
+static int number_of_chunk_islands(void)
+{
+    int i;
+    int result = 1;
+
+    for (i = 1; i < nwos_used_private_chunks; i++)
+    {
+	if (nwos_chunk_info[i-1].ref + USABLE_BLOCKS_PER_CHUNK != nwos_chunk_info[i].ref)  /* not contiguous */
+	{
+	    result++;
+	}
+    }
+
+    return result;
+}
+
+
+/* returns the info index of the last chunk in the chunk island with the fewest chunks */
+static int find_smallest_chunk_island(void)
+{
+    uint32 chunks_in_island;
+    uint32 min_chunks = nwos_used_private_chunks;
+    int i;
+    int info_index = nwos_used_private_chunks - 1;
+
+    i = 1;
+
+    while (i < nwos_used_private_chunks)
+    {
+	chunks_in_island = 1;
+
+	while (nwos_chunk_info[i-1].ref + USABLE_BLOCKS_PER_CHUNK == nwos_chunk_info[i].ref)    /* count contiguous chunks */
+	{
+	    chunks_in_island++;
+	    i++;
+	}
+
+	if (chunks_in_island < min_chunks)
+	{
+	    info_index = i - 1;
+	    min_chunks = chunks_in_island;
+	}
+
+	i++;
+    }
+
+    return info_index;
+}
+
+
+static uint32 find_new_random_chunk_location(uint32 needed_chunks)
+{
+    uint32 lower_ref;
+    uint32 upper_ref;
+    uint32 num_chunks;
+    uint32 ref = 0;
+    int i;
+
+    lower_ref = MINIMUM_PRIVATE_REFERENCE;
+    upper_ref = nwos_chunk_info[0].ref;
+
+    for (i = 1; i < nwos_used_private_chunks; i++)
+    {
+	if (nwos_chunk_info[i-1].ref + USABLE_BLOCKS_PER_CHUNK != nwos_chunk_info[i].ref)  /* not contiguous */
+	{
+	    if (nwos_chunk_info[i].ref - nwos_chunk_info[i-1].ref > upper_ref - lower_ref)
+	    {
+		lower_ref = nwos_chunk_info[i-1].ref;
+		upper_ref = nwos_chunk_info[i].ref;
+	    }
+	}
+    }
+
+    if (MAXIMUM_PRIVATE_REFERENCE + 1 - nwos_chunk_info[i-1].ref > upper_ref - lower_ref)
+    {
+	lower_ref = nwos_chunk_info[i-1].ref;
+	upper_ref = MAXIMUM_PRIVATE_REFERENCE + 1;
+    }
+
+    assert((lower_ref - MINIMUM_PRIVATE_REFERENCE) % USABLE_BLOCKS_PER_CHUNK == 0);
+    assert((upper_ref - MINIMUM_PRIVATE_REFERENCE) % USABLE_BLOCKS_PER_CHUNK == 0);
+
+    num_chunks = (upper_ref - lower_ref) / USABLE_BLOCKS_PER_CHUNK;
+
+    if (needed_chunks <= num_chunks)
+    {
+	ref = lower_ref + (random() % (num_chunks - needed_chunks)) * USABLE_BLOCKS_PER_CHUNK;
+
+	assert((ref - MINIMUM_PRIVATE_REFERENCE) % USABLE_BLOCKS_PER_CHUNK == 0);
+    }
+
+    return ref;
+}
+
+
 bool nwos_check_blocks_available(uint32 estimated_blocks)
 {
     uint32 total_blocks;
@@ -399,8 +511,10 @@ bool nwos_check_blocks_available(uint32 estimated_blocks)
     uint32 max;
 #endif
     uint32 ref;
+    uint32 offset;
     char msg[80];
     int i;
+    int num_islands;
     int info_index = -1;
 
 
@@ -550,16 +664,73 @@ bool nwos_check_blocks_available(uint32 estimated_blocks)
 
 	if (info_index < 0)
 	{
-	    fprintf(stderr, "WARNING: could not find contiguous chunks for storage\n");
-
-	    for (info_index = 0; info_index < nwos_used_private_chunks; info_index++)
+	    if (nwos_archive_is_block_device() && nwos_used_private_chunks == nwos_total_private_chunks)
 	    {
-		if (nwos_chunk_info[info_index].used < USABLE_BLOCKS_PER_CHUNK) break;
+		fprintf(stderr, "WARNING: could not find contiguous chunks for storage and cannot allocate more chunks because archive is full\n");
+
+		for (info_index = 0; info_index < nwos_used_private_chunks; info_index++)    /* let the pieces fall where they may */
+		{
+		    if (nwos_chunk_info[info_index].used < USABLE_BLOCKS_PER_CHUNK) break;
+		}
+	    }
+	    else   /* make more room */
+	    {
+		needed_chunks = (estimated_blocks + USABLE_BLOCKS_PER_CHUNK - 1) / USABLE_BLOCKS_PER_CHUNK;    /* new chunks needed */
+
+		if (nwos_archive_is_file())
+		{
+		    for (i = 0; i < needed_chunks; i++)
+		    {
+			nwos_write_empty_chunk(nwos_total_private_chunks);
+		    }
+		}
+
+		num_islands = number_of_chunk_islands();
+
+		if (random() % (num_islands + 1) == 0)   /* if one island there is a 50% chance of creating new, if two a 33% chance and so on */
+		{
+		    ref = find_new_random_chunk_location(needed_chunks);
+		    info_index = -1;
+		}
+		else
+		{
+		    info_index = find_smallest_chunk_island();
+		    ref = nwos_chunk_info[info_index].ref + USABLE_BLOCKS_PER_CHUNK;
+		}
+
+		for (i = 0; i < needed_chunks; i++)
+		{
+		    nwos_allocate_new_chunk(ref);
+
+		    if (info_index < 0)    /* this is the first time through, find the info_index for the chunk we just created */
+		    {
+			for (i = 0; i < nwos_used_private_chunks; i++)
+			{
+			    if (nwos_chunk_info[i].ref == ref)
+			    {
+				info_index = i;
+				break;
+			    }
+			}
+
+			assert(0 <= info_index && info_index < nwos_used_private_chunks);
+		    }
+
+		    ref += USABLE_BLOCKS_PER_CHUNK;
+		}
 	    }
 	}
     }
 
-    nwos_word_to_ref(nwos_chunk_info[info_index].ref, &last_ref);
+    if (block_estimate < 5 && nwos_chunk_info[info_index].used < 5)       /* allow random location for root objects */
+    {
+	offset = random() % (USABLE_BLOCKS_PER_CHUNK - 5);
+	nwos_word_to_ref(nwos_chunk_info[info_index].ref + offset, &last_ref);
+    }
+    else
+    {
+	nwos_word_to_ref(nwos_chunk_info[info_index].ref, &last_ref);
+    }
 
     return true;
 }
@@ -599,7 +770,7 @@ void nwos_generate_new_public_id(ObjRef* ref)
 
     nwos_used_public_blocks++;
 }
-#endif
+#else
 
 
 #ifdef CHANGE_SECURITY_TO_DENSITY
@@ -871,6 +1042,7 @@ void nwos_generate_new_private_id(ObjRef* new_ref)
     nwos_log(msg);
 #endif
 }
+#endif  /* not PUBLIC_MODE */
 
 
 void nwos_generate_new_id(ObjRef* ref)
