@@ -27,6 +27,14 @@
 --
 --
 -- $Log: list_discs.c,v $
+-- Revision 1.25.2.2  2009/06/06 12:51:32  jsedwards
+-- Changed to print white space around warning messages and print "Warning" in
+-- upper case.
+--
+-- Revision 1.25.2.1  2009/06/06 12:37:57  jsedwards
+-- Bug #2455976 - changed so that if there are disc lists but no disc copies
+-- it prints a warning message and still lists the discs.
+--
 -- Revision 1.25  2009/03/10 04:12:10  jsedwards
 -- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
 --
@@ -168,6 +176,7 @@ int main(int argc, char* argv[])
     int count;
     int copies;
     bool do_contents = false;
+    bool warning_printed = false;
     bool match;
     bool8* found_args = NULL;
 
@@ -209,6 +218,7 @@ int main(int argc, char* argv[])
 
     nwos_initialize_objectify(READ_ONLY, DEFAULT_FILE);
 
+    fputc('\n', stdout);
 
     if (!nwos_find_private_class_definition("FILE PATH", &path_class_ref))
     {
@@ -224,20 +234,28 @@ int main(int argc, char* argv[])
 
     if (!nwos_find_private_class_definition("DISC COPY", &copy_class_ref))
     {
-	fprintf(stderr, "No private disc copies found.\n");
-	exit(1);
+	fprintf(stderr, "WARNING: no private disc copies found.\n");
+	void_reference(&copy_class_ref);
+	warning_printed = true;
     }
 
     if (!nwos_find_private_class_definition("STORAGE LOCATION", &loc_class_ref))
     {
-	fprintf(stderr, "Warning: no locations found.\n");
+	fprintf(stderr, "WARNING: no locations found.\n");
 	void_reference(&loc_class_ref);
+	warning_printed = true;
     }
 
     if (!nwos_find_private_class_definition("PERSON", &person_class_ref))
     {
-	fprintf(stderr, "Warning: no persons found.\n");
+	fprintf(stderr, "WARNING: no persons found.\n");
 	void_reference(&person_class_ref);
+	warning_printed = true;
+    }
+
+    if (warning_printed)     /* add some white space to make it easier to see */
+    {
+	fputc('\n', stderr);
     }
 
     nwos_read_class_definition(&list_class_ref, &class_def_obj);
@@ -292,7 +310,7 @@ int main(int argc, char* argv[])
 		{
 		    nwos_get_object_class(&disc_list_ref_list->references[j], &object_class);
 
-		    if (is_same_object(&object_class, &copy_class_ref))
+		    if (!is_void_reference(&copy_class_ref) && is_same_object(&object_class, &copy_class_ref))
 		    {
 			copies++;
 
