@@ -27,6 +27,11 @@
 --
 --
 -- $Log: log_disc.c,v $
+-- Revision 1.42.2.1  2009/06/06 14:27:40  jsedwards
+-- Fix Bug #2740516 - Moved get_input function to new dialog.c file, renamed it
+-- to nwos_ask_user, and changed to call it.  Created new get_number function
+-- that checks the return value from fgets string and changed to call it.
+--
 -- Revision 1.42  2009/04/04 15:41:51  jsedwards
 -- Fix copyright years.  NO code changes.
 --
@@ -188,23 +193,22 @@ static char* file_names[MAX_FILES_PER_DISC_LIST];
 static ObjRef files[MAX_FILES_PER_DISC_LIST];
 
 
-static void get_input(char* descr, char* buffer, size_t size)
+static void get_number(char* buffer, size_t bufsize)
 {
-    char *ptr;
-
-    while (1)
+    if (fgets(buffer, bufsize, stdin) == NULL)
     {
-	printf("%s: ", descr);
-	fflush(stdout);
-	fgets(buffer, size, stdin);
-	ptr = strchr(buffer, '\n');
-	if (ptr != NULL)
+	fputc('\n', stderr);
+
+	if (feof(stdin))
 	{
-	    *ptr = '\0';
-	    break;
+	    fprintf(stderr, "ERROR: received end of input from standard input when reading number\n");
+	    exit(1);
+	}
+	else
+	{
+	    perror("reading number");
+	    exit(1);
 	}
-	do { fgets(buffer, size, stdin); } while (strchr(buffer, '\n') == NULL);
-	printf("input too long - try again!\n");
     }
 }
 
@@ -402,7 +406,7 @@ int main(int argc, char* argv[])
 	printf("Copy number: ");
 	fflush(stdout);
 
-	fgets(copy_num, sizeof(copy_num), stdin);
+	get_number(copy_num, sizeof(copy_num));
 
 	p = strchr(copy_num, '\n');   /* find the newline char */
 
@@ -410,7 +414,7 @@ int main(int argc, char* argv[])
 	{
 	    while (p == NULL)   /* keep reading until we find the newline char */
 	    {
-		fgets(copy_num, sizeof(copy_num), stdin);
+		get_number(copy_num, sizeof(copy_num));
 		p = strchr(copy_num, '\n');   /* find the newline char */
 	    }
 	    printf("copy number can only be 1 digit in this version\n");
@@ -453,7 +457,7 @@ int main(int argc, char* argv[])
 	printf("Selection: ");
 	fflush(stdout);
 
-	fgets(binder_num, sizeof(binder_num), stdin);
+	get_number(binder_num, sizeof(binder_num));
 
 	p = strchr(binder_num, '\n');   /* find the newline char */
 
@@ -461,7 +465,7 @@ int main(int argc, char* argv[])
 	{
 	    while (p == NULL)    /* keep reading until we find the newline char */
 	    {
-		fgets(binder_num, sizeof(binder_num), stdin);
+		get_number(binder_num, sizeof(binder_num));
 		p = strchr(binder_num, '\n');   /* find the newline char */
 	    }
 	    printf("storage binder can only be 1 or 2 digits in this version\n");
@@ -477,7 +481,7 @@ int main(int argc, char* argv[])
 	    }
 	    else if (binder_num[0] == '0' && binder_num[1] == '\0')      /* create a new name */
 	    {
-		get_input("name", name, sizeof(name));
+		nwos_ask_user("name", name, sizeof(name));
 
 		if (nwos_create_storage_location(name, &location_ref[num_locations]) == CREATED_NEW)
 		{
@@ -520,7 +524,7 @@ int main(int argc, char* argv[])
 
     if (binder == -1)
     {
-	get_input("name", name, sizeof(name));
+	nwos_ask_user("name", name, sizeof(name));
 
 	if (nwos_find_person(name, &person_ref))
 	{
