@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2005-2008  QRW Software
+--                 Copyright (C) 2005-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,17 @@
 --
 --
 -- $Log: number.c,v $
+-- Revision 1.13  2009/03/10 11:42:32  jsedwards
+-- Moved MAX_DIGITS and MAX_CARDINAL_NUMBER_SIZE defines to the objectify.h
+-- file and renamed to MAX_CARDINAL_NUMBER_DIGITS and
+-- MAX_CARDINAL_NUMBER_OBJ_SIZE.
+--
+-- Revision 1.12  2009/03/10 02:14:43  jsedwards
+-- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
+--
+-- Revision 1.11  2009/03/08 00:13:54  jsedwards
+-- Changed include objectify_private.h to objectify.h.
+--
 -- Revision 1.10  2008/09/01 00:10:52  jsedwards
 -- Fix copyright year.  NO code changes.
 --
@@ -71,10 +82,7 @@
 #include <string.h>
 
 #include "crc32.h"
-#include "objectify_private.h"
-
-
-#define MAX_DIGITS 127
+#include "objectify.h"
 
 
 
@@ -82,7 +90,7 @@ static size_t get_cardinal_object_size(void* cardinal_obj)
 {
     int count = ((C_struct_Cardinal_Number*)cardinal_obj)->count;
 
-    assert(0 < count && count <= MAX_DIGITS);
+    assert(0 < count && count <= MAX_CARDINAL_NUMBER_DIGITS);
 
     return sizeof(C_struct_Cardinal_Number) + count;
 }
@@ -120,7 +128,7 @@ static char* skip_leading_zeros(char* number)
 bool nwos_find_cardinal_number(char* number, ObjRef* ref)
 {
     C_struct_Class_Definition class_def_obj;
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CARDINAL_NUMBER_OBJ_SIZE];
     C_struct_Cardinal_Number* cardinal_obj_ptr = (C_struct_Cardinal_Number*)kludge;
     ObjRef cardinal_class_ref;
     ObjRef class_ref;
@@ -136,7 +144,7 @@ bool nwos_find_cardinal_number(char* number, ObjRef* ref)
 
     num_digits = strlen(ptr_first_digit);
 
-    assert(num_digits <= MAX_DIGITS);
+    assert(num_digits <= MAX_CARDINAL_NUMBER_DIGITS);
 
 
     assert(nwos_find_public_class_definition("CARDINAL NUMBER", &cardinal_class_ref));
@@ -179,7 +187,7 @@ bool nwos_find_cardinal_number(char* number, ObjRef* ref)
 
 ObjCreateResult nwos_create_cardinal_number(char* number, ObjRef* ref)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CARDINAL_NUMBER_OBJ_SIZE];
     C_struct_Cardinal_Number* ptr_cardinal_obj = (C_struct_Cardinal_Number*)kludge;
     ObjCreateResult result = FOUND_EXISTING;
     ObjRef class_ref;
@@ -192,7 +200,7 @@ ObjCreateResult nwos_create_cardinal_number(char* number, ObjRef* ref)
 
     num_digits = strlen(ptr_first_digit);
 
-    assert(num_digits <= MAX_DIGITS);
+    assert(num_digits <= MAX_CARDINAL_NUMBER_DIGITS);
 
 
     /* first find out if we already have this cardinal_number */
@@ -256,7 +264,7 @@ static bool is_cardinal_number(ObjRef* ref)
 
 void nwos_cardinal_number_to_string(ObjRef* ref, char* string, size_t size)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CARDINAL_NUMBER_OBJ_SIZE];
     C_struct_Cardinal_Number* cardinal_obj_ptr = (C_struct_Cardinal_Number*)kludge;
     int i;
 
