@@ -27,6 +27,19 @@
 --
 --
 -- $Log: objectify.c,v $
+-- Revision 1.195.2.4  2009/06/07 15:08:16  jsedwards
+-- Fix Bug #2802374 - change to allocate a new chunk if the archive is a file.
+--
+-- Revision 1.195.2.3  2009/06/06 14:41:40  jsedwards
+-- Moved nwos_ask_yes_or_no function to new dialog.c file.
+--
+-- Revision 1.195.2.2  2009/05/23 03:45:46  jsedwards
+-- Removed ifndef public mode around call to nwos_terminate_objectify because
+-- it needs to be called in public mode too.
+--
+-- Revision 1.195.2.1  2009/05/18 12:38:49  jsedwards
+-- Changed so nwos_remove_object is not compiled in public mode.
+--
 -- Revision 1.195  2009/04/01 14:44:59  jsedwards
 -- Added call to check blocks available in create root so that last_ref is set.
 --
@@ -1243,7 +1256,7 @@ void nwos_create_root(void)
     nwos_crc32_initialize();
     nwos_initialize_disk_io(READ_WRITE, DEFAULT_FILE);
 
-    assert(nwos_total_private_chunks > nwos_used_private_chunks);
+    assert(nwos_archive_is_file() || nwos_total_private_chunks > nwos_used_private_chunks);
 
     public_root_obj_ref.id[0] = 0;
     public_root_obj_ref.id[1] = 0;
@@ -1295,6 +1308,11 @@ void nwos_create_root(void)
 
     /* create the private root object */
 
+    if (nwos_archive_is_file())
+    {
+	nwos_write_empty_chunk(nwos_total_private_chunks);
+    }
+
     nwos_allocate_new_chunk(nwos_ref_to_word(&private_root_obj_ref));
 
     nwos_check_blocks_available(3);
@@ -1381,9 +1399,7 @@ void nwos_terminate_objectify()
 
     nwos_ready = false;
 
-#ifndef PUBLIC_MODE
     nwos_flush_dirty_ref_lists();  /* flush any reference lists that are dirty out to disk */
-#endif
 
     nwos_terminate_disk_io();
 
@@ -1863,6 +1879,7 @@ void nwos_overwrite_object_to_disk(ObjRef* ref, void* object, size_t size)
 }
 
 
+#ifndef PUBLIC_MODE
 void nwos_remove_object(ObjRef* ref)
 {
     /* this function should read the object and erase all blocks, functions should not call this to erase a block, they should call erase_block */
@@ -1873,6 +1890,7 @@ void nwos_remove_object(ObjRef* ref)
 
     nwos_erase_block(ref);
 }
+#endif
 
 
 void nwos_write_public_object_to_disk(ObjRef* ref, void* object, size_t size)
@@ -1998,39 +2016,3 @@ bool nwos_is_quit_command(char* command)
 }
 
 
-bool nwos_ask_yes_or_no(char* statement, char* question)
-{
-    char buffer[16];
-
-    if (statement != NULL)
-    {
-	printf("%s.  %s? (y/n): ", statement, question);
-    }
-    else
-    {
-	printf("%s? (y/n): ", question);
-    }
-
-    while (1)
-    {
-	fflush(stdout);
-	fgets(buffer, sizeof(buffer), stdin);
-	printf("\n");
-
-	if (strchr(buffer, '\n') == NULL)  /* too much input */
-	{
-	    while(strchr(buffer, '\n') == NULL) fgets(buffer, sizeof(buffer), stdin);
-	    buffer[0] = '\0';
-	}
-
-	if (strcasecmp(buffer, "y\n") == 0 || strcasecmp(buffer, "yes\n") == 0) break;
-
-	if (strcasecmp(buffer, "n\n") == 0 || strcasecmp(buffer, "no\n") == 0) break;
-
-	printf("Please answer the question: %s (yes or no)\n", question);
-    }
-
-    return (tolower(buffer[0]) == 'y');
-}
-
-
