@@ -27,6 +27,9 @@
 --
 --
 -- $Log: objectify.h,v $
+-- Revision 1.165.2.1  2009/06/06 15:01:41  jsedwards
+-- Added external declaration for new nwos_ask_user function in dialog.c file.
+--
 -- Revision 1.165  2009/03/14 22:37:57  jsedwards
 -- Moved reference_list related declarations to reference_list.h file.
 --
@@ -870,6 +873,7 @@ extern bool nwos_find_public_acronym(char* acronym, ObjRef* ref);
 extern bool nwos_acronym_to_string(ObjRef* ref, char* string, size_t size);
 
 extern bool nwos_is_quit_command(char* command);
+extern void nwos_ask_user(char* descr, char* buffer, size_t size);
 extern bool nwos_ask_yes_or_no(char* statement, char* question);
 
 
