@@ -27,6 +27,10 @@
 --
 --
 -- $Log: person.c,v $
+-- Revision 1.27.2.1  2009/06/06 14:59:35  jsedwards
+-- Moved get_input function to new dialog.c file, renamed it to nwos_ask_user,
+-- and changed to call it.
+--
 -- Revision 1.27  2009/03/07 15:09:02  jsedwards
 -- Removed include of objectify_private.h and changed to call
 -- nwos_generate_new_id instead of nwos_generate_new_completely_random_id.
@@ -458,27 +462,6 @@ ObjCreateResult nwos_create_ssn(ObjRef* person, char* number, ObjRef* ref)
 #endif
 
 
-static void get_input(char* descr, char* buffer, size_t size)
-{
-    char *ptr;
-
-    while (1)
-    {
-	printf("%s: ", descr);
-	fflush(stdout);
-	fgets(buffer, size, stdin);
-	ptr = strchr(buffer, '\n');
-	if (ptr != NULL)
-	{
-	    *ptr = '\0';
-	    break;
-	}
-	do { fgets(buffer, size, stdin); } while (strchr(buffer, '\n') == NULL);
-	printf("input too long - try again!\n");
-    }
-}
-
-
 static void check_public(char* name)
 {
     ObjRef ref;
@@ -514,12 +497,12 @@ void nwos_add_person()
     ok = false;
     while (!ok)
     {
-	get_input("gender", gender, sizeof(gender));
+	nwos_ask_user("gender", gender, sizeof(gender));
 	ok = nwos_is_valid_gender(gender);
 	if (!ok) printf("must input either 'male' or 'female' or simply 'm' or 'f'\n");
     }
 
-    get_input("last name", last_name, sizeof(last_name));
+    nwos_ask_user("last name", last_name, sizeof(last_name));
     if (*last_name == '\0')
     {
 	printf("Error: this version cannot create a person without the last name.\n");
@@ -527,7 +510,7 @@ void nwos_add_person()
     }
     check_public(last_name);
 
-    get_input("first name", first_name, sizeof(first_name));
+    nwos_ask_user("first name", first_name, sizeof(first_name));
     if (*first_name == '\0')
     {
 	printf("Error: this version cannot create a person without the first name.\n");
@@ -535,19 +518,19 @@ void nwos_add_person()
     }
     check_public(first_name);
 
-    get_input("middle name", middle_name, sizeof(middle_name));
+    nwos_ask_user("middle name", middle_name, sizeof(middle_name));
     if (*middle_name != '\0')
     {
 	check_public(middle_name);
     }
 
-    get_input("goes by", goes_by, sizeof(goes_by));
+    nwos_ask_user("goes by", goes_by, sizeof(goes_by));
     if (*goes_by != '\0')
     {
 	check_public(goes_by);
     }
 
-    get_input("nick name", nickname, sizeof(nickname));
+    nwos_ask_user("nick name", nickname, sizeof(nickname));
     if (*nickname != '\0')
     {
 	check_public(nickname);
@@ -556,7 +539,7 @@ void nwos_add_person()
 
     if (toupper(*gender) == 'F')
     {
-	get_input("maiden name", maiden_name, sizeof(maiden_name));
+	nwos_ask_user("maiden name", maiden_name, sizeof(maiden_name));
 	if (*maiden_name != '\0')
 	{
 	    check_public(maiden_name);
@@ -570,7 +553,7 @@ void nwos_add_person()
     ok = false;
     while (!ok)
     {
-	get_input("birth date M/D/YYYY", birth_date, sizeof(birth_date));
+	nwos_ask_user("birth date M/D/YYYY", birth_date, sizeof(birth_date));
 	if (*birth_date == '\0')
 	{
 	    ok = true;    /* none given */
@@ -942,7 +925,7 @@ bool nwos_find_person(char* name, ObjRef* person_ref)
 	    ok = false;
 	    while (!ok)
 	    {
-		get_input("selection number", buffer, sizeof(buffer));
+		nwos_ask_user("selection number", buffer, sizeof(buffer));
 
 		printf("\n");
 
