@@ -27,6 +27,10 @@
 --
 --
 -- $Log: phone.c,v $
+-- Revision 1.28.2.1  2009/06/06 14:59:35  jsedwards
+-- Moved get_input function to new dialog.c file, renamed it to nwos_ask_user,
+-- and changed to call it.
+--
 -- Revision 1.28  2009/03/07 20:17:19  jsedwards
 -- Removed #include of objectify_private.h, not needed.
 --
@@ -554,31 +558,6 @@ bool nwos_phone_number_to_string(ObjRef* ref, char* string, size_t size)
 
 
 
-
-/* FIX THIS! - need a common get input routine, instead of duplicating this in every file! */
-
-static void get_input(char* descr, char* buffer, size_t size)
-{
-    char *ptr;
-
-    while (1)
-    {
-	printf("%s: ", descr);
-	fflush(stdout);
-	fgets(buffer, size, stdin);
-	ptr = strchr(buffer, '\n');
-	if (ptr != NULL)
-	{
-	    *ptr = '\0';
-	    break;
-	}
-	do { fgets(buffer, size, stdin); } while (strchr(buffer, '\n') == NULL);
-	printf("input too long - try again!\n");
-    }
-}
-
-
-
 static bool parse_phone_number(char* phone_number, char area_code[], char number[])
 {
     static char* patterns[] =
@@ -764,7 +743,7 @@ void nwos_add_mobile_phone(char* name, char* phone_number)
 	{
 	    while (!number_ok)
 	    {
-		get_input("What is the area code (enter `quit' to return to main command)", area_code, 16);
+		nwos_ask_user("What is the area code (enter `quit' to return to main command)", area_code, 16);
 
 		printf("\n");
 
@@ -810,7 +789,7 @@ void nwos_add_mobile_phone(char* name, char* phone_number)
 
 	while (!number_ok)
 	{
-	    get_input("What is the area code (enter `quit' to return to main command)", area_code, 16);
+	    nwos_ask_user("What is the area code (enter `quit' to return to main command)", area_code, 16);
 
 	    printf("\n");
 
@@ -856,7 +835,7 @@ void nwos_add_mobile_phone(char* name, char* phone_number)
 
 	while (!number_ok)
 	{
-	    get_input("What is the area code", area_code, 16);
+	    nwos_ask_user("What is the area code", area_code, 16);
 
 	    printf("\n");
 
@@ -880,7 +859,7 @@ void nwos_add_mobile_phone(char* name, char* phone_number)
 
 	while (!number_ok)
 	{
-	    get_input("What is the phone number", number, 16);
+	    nwos_ask_user("What is the phone number", number, 16);
 
 	    number_ok = nwos_is_valid_phone_number(number);
 
