@@ -27,6 +27,10 @@
 --
 --
 -- $Log: prep_disk.c,v $
+-- Revision 1.68.2.1  2009/06/06 15:14:52  jsedwards
+-- Fix Bug #2740516 - Added new get_response function that calls fgets and
+-- checks the return value.  Changed to call it instead of fgets.
+--
 -- Revision 1.68  2009/03/14 23:01:54  jsedwards
 -- Added include of the objectify.h file to define nwos_create_root.
 --
@@ -388,6 +392,26 @@ void print_usage(char* name)
 }
 
 
+static void get_response(char* buffer, size_t bufsize)
+{
+    if (fgets(buffer, bufsize, stdin) == NULL)
+    {
+	fputc('\n', stderr);
+
+	if (feof(stdin))
+	{
+	    fprintf(stderr, "ERROR: received end of input from standard input when reading response\n");
+	    exit(1);
+	}
+	else
+	{
+	    perror("reading responce");
+	    exit(1);
+	}
+    }
+}
+
+
 void goodbye()
 {
     fprintf(stderr, "\n");
@@ -427,7 +451,7 @@ void agree_no_warranty()
     fprintf(stderr, "Do you agree with the license terms of this software? ");
     fflush(stderr);
 
-    fgets(buffer, sizeof(buffer), stdin);
+    get_response(buffer, sizeof(buffer));
 
     if (strcmp(buffer, "I agree\n") != 0) goodbye();
 
@@ -463,7 +487,7 @@ void understand_security()
     fprintf(stderr, "Do you understand this? ");
     fflush(stderr);
 
-    fgets(buffer, sizeof(buffer), stdin);
+    get_response(buffer, sizeof(buffer));
 
     if (strcmp(buffer, "I understand\n") != 0) goodbye();
 
@@ -607,7 +631,7 @@ int main(int argc, char* argv[])
 
     fflush(stdout);
 
-    fgets(answer, sizeof(answer), stdin);
+    get_response(answer, sizeof(answer));
 
     printf("\n");
 
