@@ -27,6 +27,9 @@
 --
 --
 -- $Log: reference_list.c,v $
+-- Revision 1.45.2.1  2009/05/23 03:48:03  jsedwards
+-- Moved endif so that nwos_flush_dirty_ref_lists get compiled in public mode.
+--
 -- Revision 1.45  2009/03/14 20:25:52  jsedwards
 -- Fix bug introduced in previous check-in where seq was not set to block_num.
 --
@@ -1389,6 +1392,7 @@ void nwos_remove_from_reference_list(ObjRef* ref, ObjRef* ref_list)
 	cache->num_refs--;
     }
 }
+#endif
 
 
 /* flush any reference lists that are dirty out to disk */
@@ -1405,7 +1409,7 @@ void nwos_flush_dirty_ref_lists()
 	}
     }
 }
-#endif
+
 
 ReferenceList* nwos_malloc_reference_list(ObjRef* ref)
 {
