@@ -27,6 +27,10 @@
 --
 --
 -- $Log: remove_file.c,v $
+-- Revision 1.16.2.1  2009/06/06 15:18:44  jsedwards
+-- Fix Bug #2740516 - Changed to check return value from fgets and exit if end
+-- of file or error is returned.
+--
 -- Revision 1.16  2009/03/10 10:23:52  jsedwards
 -- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
 --
@@ -155,7 +159,21 @@ int main(int argc, char* argv[])
 
 	    fflush(stdout);
 
-	    fgets(answer, sizeof(answer), stdin);
+	    if (fgets(answer, sizeof(answer), stdin) == NULL)
+	    {
+		fputc('\n', stderr);
+
+		if (feof(stdin))
+		{
+		    fprintf(stderr, "ERROR: received end of input from standard input when reading response\n");
+		    exit(1);
+		}
+		else
+		{
+		    perror("reading response from standard input");
+		    exit(1);
+		}
+	    }
 
 	    printf("\n");
 
