@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2007-2008  QRW Software
+--                 Copyright (C) 2007-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,16 @@
 --
 --
 -- $Log: rename_file.c,v $
+-- Revision 1.21  2009/03/19 11:38:21  jsedwards
+-- Wrapped call to nwos_set_security_level with ifdef CHANGE_SECURITY_TO_DENSITY
+-- because what was called security level stuff is temporarily disabled.
+--
+-- Revision 1.20  2009/03/10 09:38:18  jsedwards
+-- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
+--
+-- Revision 1.19  2009/03/08 00:13:54  jsedwards
+-- Changed include objectify_private.h to objectify.h.
+--
 -- Revision 1.18  2008/09/01 03:13:44  jsedwards
 -- Change for new nwos_initialize_objectify calling convention (doesn't pass
 -- back root_object_reference anymore) and removed call to nwos_set_root_object
@@ -104,7 +114,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "objectify_private.h"
+#include "objectify.h"
 
 
 static size_t get_path_object_size(void* file_path_obj)
@@ -226,7 +236,7 @@ void create_new_path(char* new_path, C_struct_Path_And_File_Association *assoc_o
 int main(int argc, char* argv[])
 {
     C_struct_Path_And_File_Association assoc_obj;
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_PATH_OBJ_SIZE];
     C_struct_File_Path* ptr_path_obj = (C_struct_File_Path*)kludge;
     ObjRef list_class_ref;
     ObjRef old_path_ref;
@@ -271,7 +281,9 @@ int main(int argc, char* argv[])
 
     nwos_initialize_objectify(READ_WRITE, DEFAULT_FILE);
 
+#ifdef CHANGE_SECURITY_TO_DENSITY
     nwos_set_security_level(Security_Very_Low);
+#endif
 
     if (keep_history && !nwos_check_blocks_available(4))
     {
