@@ -27,6 +27,9 @@
 --
 --
 -- $Log: sync_archive.c,v $
+-- Revision 1.11.2.1  2009/06/06 15:20:32  jsedwards
+-- Fix Bug #2740516 - Changed to check return value from fgets.
+--
 -- Revision 1.11  2009/03/14 23:09:05  jsedwards
 -- Added includes of the new backup.h and chunk_info.h files.
 --
@@ -171,7 +174,21 @@ int main(int argc, char* argv[])
 
     fflush(stderr);
 
-    fgets(answer, sizeof(answer), stdin);
+    if (fgets(answer, sizeof(answer), stdin) == NULL)
+    {
+	fputc('\n', stderr);
+
+	if (feof(stdin))
+	{
+	    fprintf(stderr, "ERROR: received end of input from standard input\n");
+	    exit(1);
+	}
+	else
+	{
+	    perror("reading answer to question");
+	    exit(1);
+	}
+    }
 
     printf("\n");
 
