@@ -29,6 +29,14 @@
 #  This script runs a quick test of file importing and exporting.
 # 
 #  $Log: test_import_export.sh,v $
+#  Revision 1.5  2009/03/08 12:40:44  jsedwards
+#  Changed sed for computer.c file to change the word Copyright to Copyleft
+#  instead of changing the year from 2008 to 2009 (which breaks when the year
+#  really changes in the computer.c file.
+#
+#  Revision 1.4  2009/03/01 13:43:06  jsedwards
+#  Removed archive size parameter from prep_disk because it is no longer used.
+#
 #  Revision 1.3  2008/12/29 14:58:34  jsedwards
 #  Changed so that it sets the environment variables itself, does the test in
 #  the /tmp directory, tests exit codes and stops if it was incorrect, and
@@ -69,7 +77,7 @@ cd /tmp/test
 echo "---------------"
 echo " prep disk..."
 echo "---------------"
-if ! $EXEC/prep_disk 128M; then
+if ! $EXEC/prep_disk; then
    echo ""
    echo "prep_disk failed"
    echo ""
@@ -184,7 +192,7 @@ fi
 echo "---------------------"
 echo " file revision..."
 echo "---------------------"
-sed -i -e "s/2005-2008/2005-2009/" computer.c
+sed -i -e "s/Copyright/Copyleft/" computer.c
 
 echo "---------------------"
 echo " verify and remove..."
@@ -251,7 +259,7 @@ fi
 echo "--------------------------"
 echo " prep disk for restore..."
 echo "--------------------------"
-if ! $EXEC/prep_disk --no-private 128M; then
+if ! $EXEC/prep_disk --no-private; then
    echo ""
    echo "prep_disk --no-private failed"
    echo ""
