@@ -1,9 +1,10 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2004-2007  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--         This file is part of the New World OS and Objectify projects
+--                    Copyright (C) 2004-2009  QRW Software
+--              J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
+--                         http://www.qrwsoftware.com
+--                         http://nwos.sourceforge.com
+--                      http://objectify.sourceforge.com
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -27,6 +28,12 @@
 --
 --
 -- $Log: types.h,v $
+-- Revision 1.13  2009/03/14 11:54:38  jsedwards
+-- Changed to new file header with Objectify project included.
+--
+-- Revision 1.12  2009/03/13 04:37:28  jsedwards
+-- Moved various declarations from objectify.h.
+--
 -- Revision 1.11  2007/08/09 23:47:44  jsedwards
 -- Removed the junk to cope with the 64-bit filesystem junk on Linux.  Now
 -- using the _FILE_OFFSET_BITS=64 thing instead.
@@ -120,5 +127,55 @@ typedef enum { false = 0, true = 1 } bool;
 typedef signed char bool8;
 typedef signed short bool16;
 
+
+#define DEFAULT_FILE NULL      /* this used to define a path, now a null tells disk_io to use the default */
+
+typedef enum {
+  PUBLIC     = 0x50424C43,
+  READ_ONLY  = 0x52454144,
+  READ_WRITE = 0x52445752,
+} AccessType;
+
+
+#define MD5_DIGEST_SIZE    16
+#define SHA1_DIGEST_SIZE   20
+#define SHA256_DIGEST_SIZE 32
+#define SHA512_DIGEST_SIZE 64
+
+
+
+static inline void nwos_4_uint8_to_uint32(uint8* src, uint32* dst) 
+{
+    *dst = ((uint32)src[0] << 24) | ((uint32)src[1] << 16) | ((uint32)src[2] << 8) | (uint32)src[3];
+}
+
+static inline void nwos_2_uint8_to_uint16(uint8* src, uint16* dst) 
+{
+    *dst = ((uint32)src[0] << 8) | ((uint32)src[1]);
+}
+
+static inline void nwos_uint32_to_4_uint8(uint32* src, uint8* dst) 
+{
+    dst[0] = *src >> 24;
+    dst[1] = *src >> 16;
+    dst[2] = *src >> 8;
+    dst[3] = *src;
+}
+
+
+static inline uint16 byteswap_uint16(uint16 x)
+{
+    return (x << 8) | (x >> 8);
+}
+
+static inline uint32 byteswap_uint32(uint32 x)
+{
+  return (x << 24) |
+    ((x & 0x0000ff00) << 8) |
+    ((x & 0x00ff0000) >> 8) |
+    (x >> 24);
+}
+
+
 #endif
 
