@@ -27,6 +27,10 @@
 --
 --
 -- $Log: us_state.c,v $
+-- Revision 1.28.2.1  2009/06/06 14:59:35  jsedwards
+-- Moved get_input function to new dialog.c file, renamed it to nwos_ask_user,
+-- and changed to call it.
+--
 -- Revision 1.28  2009/03/07 20:17:19  jsedwards
 -- Removed #include of objectify_private.h, not needed.
 --
@@ -344,27 +348,6 @@ ObjCreateResult nwos_create_us_city(char* city, ObjRef* state_ref, ObjRef* city_
 }
 
 
-static void get_input(char* descr, char* buffer, size_t size)
-{
-    char *ptr;
-
-    while (1)
-    {
-	printf("%s: ", descr);
-	fflush(stdout);
-	fgets(buffer, size, stdin);
-	ptr = strchr(buffer, '\n');
-	if (ptr != NULL)
-	{
-	    *ptr = '\0';
-	    break;
-	}
-	do { fgets(buffer, size, stdin); } while (strchr(buffer, '\n') == NULL);
-	printf("input too long - try again!\n");
-    }
-}
-
-
 #define MAX_NAMES 20
 #define MAX_NAME_SIZE 64
 
@@ -394,7 +377,7 @@ void nwos_add_city(ObjRef* city_ref)
 
     nwos_find_public_class_definition("US CITY", &city_class_ref);
 
-    get_input("city", city, sizeof(city));
+    nwos_ask_user("city", city, sizeof(city));
 
   /* first find the name */
 
@@ -453,7 +436,7 @@ void nwos_add_city(ObjRef* city_ref)
 	    ok = false;
 	    while (!ok)
 	    {
-		get_input("selection number", buffer, sizeof(buffer));
+		nwos_ask_user("selection number", buffer, sizeof(buffer));
 
 		printf("\n");
 
@@ -488,7 +471,7 @@ void nwos_add_city(ObjRef* city_ref)
 	ok = false;
 	while (!ok)
 	{
-	    get_input(temp, state, sizeof(state));
+	    nwos_ask_user(temp, state, sizeof(state));
 
 	    printf("\n");
 
