@@ -27,6 +27,14 @@
 --
 --
 -- $Log: user_config.c,v $
+-- Revision 1.18  2009/03/14 04:08:02  jsedwards
+-- Removed include of disk_io.h file and added includes for assert.h and
+-- user_config.h files.
+--
+-- Revision 1.17  2009/03/13 13:17:26  jsedwards
+-- Removed include of objectify.h and added includes for config.h, disk_io.h,
+-- log.h, and strlcxx.h files.
+--
 -- Revision 1.16  2009/01/02 21:44:29  jsedwards
 -- Added code to read the configuration before changing the private path so
 -- that it won't be overwritten.
@@ -87,13 +95,17 @@
 --
 */
 
+#include <assert.h>
 #include <ctype.h>
 #include <limits.h>    /* define PATH_MAX */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include "objectify.h"
+#include "config.h"
+#include "log.h"
+#include "strlcxx.h"           /* in case strlcpy and strlcat are not provided by the system */
+#include "user_config.h"
 
 
 static bool config_file_has_been_read;
